@@ -749,9 +749,7 @@ class Model(ABC):
             gridspec_kw={"height_ratios": [0.05, 1, 1]},
             num='AC susceptibility fits'
         )  # 8.27, 11.69 A4
-        fig.subplots_adjust(hspace=.5, wspace=.02)
-
-        ax1.xaxis.set_ticks_position('top')
+        fig.subplots_adjust(hspace=.05, wspace=.02)
 
         fitted_temps = [
             model.fit_temperature for model in models if model.fit_status
@@ -827,6 +825,9 @@ class Model(ABC):
 
         gui.create_ac_temp_colorbar(ax1, fig, fitted_temps, colors)
 
+        ax1.xaxis.set_ticks_position('top')
+        ax1.xaxis.set_label_position('top')
+
         ax2.set_xticklabels([])
         ax2.set_ylabel(r'$\chi^{,}$  (cm$^{3}$mol$^{-1}$)')
         # Get rid of the frames of susceptibility plots
@@ -2221,15 +2222,30 @@ def interactive_t_select(experiments: list[Experiment]):
 
     n_temps = unique_temps.size
 
-    n_rows = int(np.ceil(n_temps/4))
+    if n_temps == 1:
+        n_cols = 1
+    elif n_temps < 5:
+        n_cols = 2
+    elif n_temps < 10:
+        n_cols = 3
+    elif n_temps < 17:
+        n_cols = 4
+    else:
+        n_cols = 5
+
+    n_rows = int(np.ceil(n_temps/n_cols))
+
+    figsize = 7./3. * n_rows
+    if figsize > 7:
+        figsize = 7
 
     # Show each data set individually for identification of peaks
     fig, axs = plt.subplots(
         n_rows,
-        4,
+        n_cols,
         sharex='none',
         sharey='none',
-        figsize=(7, 7),
+        figsize=(figsize, figsize),
         num="Select temperatures to fit",
     )
 
@@ -2239,7 +2255,8 @@ def interactive_t_select(experiments: list[Experiment]):
         experiments[0].dc_field
     )
 
-    suptitle += "\n Select (click) the temperatures to fit (green), then close this window." # noqa
+    suptitle += "\n Select (click) the temperatures to fit (green)"
+    suptitle += "\n then close this window."
 
     fig.subplots_adjust(hspace=.4, wspace=.08)
     plt.suptitle(suptitle, fontsize=11)
@@ -2250,7 +2267,6 @@ def interactive_t_select(experiments: list[Experiment]):
             experiment.sus_im,
             marker='o',
             markeredgewidth=1,
-            label="{:.2f} K".format(experiment.temperatures[0]),
             markeredgecolor='b',
             markerfacecolor='w',
             markersize=5,
@@ -2258,16 +2274,13 @@ def interactive_t_select(experiments: list[Experiment]):
             lw=.5
         )
         ax.set_yticklabels([])
+        ax.set_yticks([])
         ax.set_xticklabels([])
-        ax.legend(
-            loc=0,
-            fontsize='small',
-            markerscale=0,
-            handlelength=0,
-            numpoints=1,
-            ncol=1,
-            frameon=False
-        )
+        ax.set_xticks([])
+
+        ax.set_xlabel("{:.2f} K".format(experiment.temperatures[0]))
+
+        ax.set_box_aspect(aspect=1)
 
     # Remove empty axes
     for _ in range(len(axs)-n_temps):
@@ -2277,6 +2290,8 @@ def interactive_t_select(experiments: list[Experiment]):
     for ax in axs:
         ax.set_facecolor("White")
 
+    fig.tight_layout()
+
     # Store object, one per temperature
     stores = [Toggle(temp) for temp in unique_temps]
 
