@@ -341,17 +341,17 @@ def dc_mode_func(args):
         # Define Meq in case --M_eq Multiple is indicated.
         meq_multiple = []
         if args.M_eq == 'multiple':
-            if not os.path.isfile('Multiple_Meq_{:d}Oe.txt'.format(field)):
+            if not os.path.isfile('Multiple_Meq_{:}Oe.txt'.format(str(field))):
                 print('\n    ***Error***:')
                 print(
                     '    --M_eq multiple specified but',
-                    ' Multiple_Meq_{:d}Oe.txt is not present.'.format(
-                        field
+                    ' Multiple_Meq_{:}Oe.txt is not present.'.format(
+                        str(field)
                     )
                 ) # noqa
             else:
                 meq_multiple = np.loadtxt(
-                    'Multiple_Meq_{}Oe.txt'.format(int(field)), skiprows=1
+                    'Multiple_Meq_{:}Oe.txt'.format(str(field)), skiprows=1
                 )
 
         # Define the output files.
