@@ -205,6 +205,22 @@ class Process_Waveform():
         M_err = data[:, 4]
         temperature = np.round(data[:, 1][0], decimals=1)
 
+        # Add artificial points at start and end to help define data blocks
+        # in slice_data() later on
+        to_add = np.mean(self.field_window)
+        time = np.pad(
+            time, (20, 20), mode='constant', constant_values=0
+            )  # mode='linear_ramp', end_values=((?, ?))
+        field = np.pad(
+            field, (20, 20), mode='constant', constant_values=int(to_add)
+            )
+        moment = np.pad(
+            moment, (20, 20), mode='constant', constant_values=1
+            )
+        M_err = np.pad(
+            M_err, (20, 20), mode='constant', constant_values=1E-5
+            )
+
         # Define the indices of the measured points that are not noisy
         # (to keep).
         # create a boolean mask for noisy data. Threshold is 0.3. We keep data
@@ -391,7 +407,7 @@ class Process_Waveform():
         moment = [
             Moments[csum[i]:csum[i+1]] for i in range(len(csum)-1)
             ]
-        ''' # noqa
+        '''  # noqa
 
         '''
         if len(time) != args.nfrequencies:
@@ -400,7 +416,7 @@ class Process_Waveform():
      Please use a different --field_window option.'.format(
                 len(time), args.nfrequencies)
             )
-        ''' # noqa
+        '''  # noqa
 
         return time, field, moment
 
@@ -430,8 +446,6 @@ class Process_Waveform():
             ax3 = ax1.twinx()
             ax4 = ax2.twinx()
 
-            
-
             # Refer the time to first point within each set.
             _time = time[i]-time[i][0]
 
@@ -678,9 +692,9 @@ class Process_Waveform():
             # Unpack the data.
             indxs = [ij for ij, val in enumerate(temps) if val == temp]
 
-            freq = [i[1] for i in sus[indxs[0]:indxs[-1]]]
-            sus_re = [i[2] for i in sus[indxs[0]:indxs[-1]]]
-            sus_im = [i[3] for i in sus[indxs[0]:indxs[-1]]]
+            freq = [i[1] for i in sus[indxs[0]:indxs[-1]+1]]
+            sus_re = [i[2] for i in sus[indxs[0]:indxs[-1]+1]]
+            sus_im = [i[3] for i in sus[indxs[0]:indxs[-1]+1]]
 
             # Plot data
             ax1.plot(freq, sus_re, marker='o', lw=1, label='{} K'.format(temp))
@@ -691,7 +705,7 @@ class Process_Waveform():
             axis.legend(
                 loc=0, fontsize='x-small', markerscale=0.6,
                 handlelength=0.4, labelspacing=0.2, handletextpad=0.4,
-                numpoints=1, ncol=int(len(np.unique(temps))/2), frameon=False
+                numpoints=1, ncol=len(sus), frameon=False
                 )
 
         ax2.set_xscale('log')
